import React, {useEffect, useState} from "react";
import ProjectCard from "../../ui/ProjectCard/ProjectCard";
import './Projects.scss';

type ProjectsState = {
    done: ProjectType[]
    dropped: ProjectType[]
}

const Projects = () => {
    const [projects, setProjects] = useState<ProjectsState>({done: [], dropped: []});
    const [loading, setLoading] = useState(true);

    useEffect(() => {
        fetch('https://baka.nix13.pw/projects')
            .then(r => r.json())
            .then(r => setProjects(r.projects))
            .then(_ => setLoading(false));
    }, []);

    if(loading) return <div>Грузится, бля...</div>
    return (
        <div className="Projects" id='Projects'>
            <h2>Завершенные и в разработке</h2>
            <div className="Projects__List">
                {projects.done.map(project => (
                    <ProjectCard
                        key={project.name}
                        title={project.name} status={project.status}
                        links={project.links}
                    >{project.desc}</ProjectCard>
                ))}
            </div>

            <h2>Замороженные и брошенные</h2>
            <div className="Projects__List">
                {projects.dropped.map(project => (
                    <ProjectCard
                        key={project.name}
                        title={project.name} status={project.status}
                        links={project.links}
                    >{project.desc}</ProjectCard>
                ))}

            </div>
        </div>
    );
}

export default Projects;